@@ -373,7 +373,7 @@ static libGAP_Int libGAP_InitKernel (
     libGAP_StructInitInfo *    libGAP_module )
 {
     /* install the marking functions for boolean values                    */
-    libGAP_InfoBags[ libGAP_T_BOOL ].name = "boolean";
+    libGAP_InfoBags[ libGAP_T_BOOL ].name = "boolean or fail";
     libGAP_InitMarkFuncBags( libGAP_T_BOOL, libGAP_MarkNoSubBags );
 
     /* init filters and functions                                          */
