@@ -74,6 +74,10 @@
 #include        "plist.h"               /* plain lists                     */
 #include        "string.h"              /* strings                         */
 
+#include	"code.h"		/* coder                           */
+#include	"thread.h"		/* threads			   */
+#include	"tls.h"			/* thread-local storage		   */
+
 
 /****************************************************************************
 **
@@ -1752,9 +1756,9 @@ void    libGAP_UnmarkAEClass(
 
 /****************************************************************************
 **
-*F  Funcposition( <self>, <vector> )
+*F  FuncDT_evaluation( <self>, <vector> )
 **
-**  Funcposition implements the internal function
+**  FuncDT_evaluation implements the internal function
 **
 **  DT_evaluation( <vector> ).
 **
@@ -1762,7 +1766,7 @@ void    libGAP_UnmarkAEClass(
 **  monomials.  DT_evaluation is called from the library function dt_add.
 */
 
-libGAP_Obj    libGAP_Funcposition(libGAP_Obj      self,
+libGAP_Obj    libGAP_FuncDT_evaluation(libGAP_Obj      self,
                     libGAP_Obj      vector)
 {
     libGAP_UInt   res,i;
@@ -1802,7 +1806,7 @@ static libGAP_StructGVarFunc libGAP_GVarFuncs [] = {
       libGAP_FuncGetPols, "src/dt.c:GetPols" },
     
     { "DT_evaluation", 1, "vector",
-      libGAP_Funcposition, "src/dt.c:DT_evaluation" },
+      libGAP_FuncDT_evaluation, "src/dt.c:DT_evaluation" },
 
     { 0 }
 
@@ -1863,7 +1867,6 @@ static libGAP_StructInitInfo libGAP_module = {
 
 libGAP_StructInitInfo * libGAP_InitInfoDeepThought ( void )
 {
-    libGAP_FillInVersion( &libGAP_module );
     return &libGAP_module;
 }
 
