@@ -42,13 +42,19 @@
 
 #include        "code.h"                /* coder                           */
 #include        "calls.h"
-#include        "vars.h"                /* variables                       */
 #include        "stats.h"
 
 
 #include        "exprs.h"               /* expressions                     */
 
-#include <assert.h>
+#include        "tls.h"                 /* thread-local storage            */
+#include        "profile.h"             /* installing methods              */
+#include        "aobjects.h"            /* atomic objects                  */
+
+#include        "vars.h"                /* variables                       */
+
+#include	<assert.h>
+
 
 /****************************************************************************
 **
@@ -67,8 +73,8 @@
 #endif
 #ifndef NO_LVAR_CHECKS
 #define OBJ_REFLVAR(expr)       \
-                        (*(Obj*)(((char*)PtrLVars)+(expr)+5) != 0 ? \
-                         *(Obj*)(((char*)PtrLVars)+(expr)+5) : \
+                        (*(Obj*)(((char*)TLS(PtrLVars))+(expr)+5) != 0 ? \
+                         *(Obj*)(((char*)TLS(PtrLVars))+(expr)+5) : \
                          ObjLVar( LVAR_REFLVAR( expr ) ) )
 #endif
 */
@@ -2018,111 +2024,111 @@ static libGAP_Int libGAP_InitKernel (
     
     /* clear the evaluation dispatch table                                 */
     for ( type = 0; type < 256; type++ ) {
-        libGAP_EvalExprFuncs[ type ] = libGAP_EvalUnknownExpr;
-        libGAP_EvalBoolFuncs[ type ] = libGAP_EvalUnknownBool;
+        libGAP_InstallEvalExprFunc( type , libGAP_EvalUnknownExpr);
+        libGAP_InstallEvalBoolFunc( type , libGAP_EvalUnknownBool);
     }
 
     /* install the evaluators for logical operations                       */
-    libGAP_EvalExprFuncs [ libGAP_T_OR             ] = libGAP_EvalOr;   
-    libGAP_EvalExprFuncs [ libGAP_T_AND            ] = libGAP_EvalAnd;  
-    libGAP_EvalExprFuncs [ libGAP_T_NOT            ] = libGAP_EvalNot;  
+    libGAP_InstallEvalExprFunc( libGAP_T_OR             , libGAP_EvalOr);   
+    libGAP_InstallEvalExprFunc( libGAP_T_AND            , libGAP_EvalAnd);  
+    libGAP_InstallEvalExprFunc( libGAP_T_NOT            , libGAP_EvalNot);  
 
     /* the logical operations are guaranteed to return booleans            */
-    libGAP_EvalBoolFuncs [ libGAP_T_OR             ] = libGAP_EvalOr;
-    libGAP_EvalBoolFuncs [ libGAP_T_AND            ] = libGAP_EvalAnd;
-    libGAP_EvalBoolFuncs [ libGAP_T_NOT            ] = libGAP_EvalNot;
+    libGAP_InstallEvalBoolFunc( libGAP_T_OR             , libGAP_EvalOr);
+    libGAP_InstallEvalBoolFunc( libGAP_T_AND            , libGAP_EvalAnd);
+    libGAP_InstallEvalBoolFunc( libGAP_T_NOT            , libGAP_EvalNot);
 
     /* install the evaluators for comparison operations                    */
-    libGAP_EvalExprFuncs [ libGAP_T_EQ             ] = libGAP_EvalEq;   
-    libGAP_EvalExprFuncs [ libGAP_T_NE             ] = libGAP_EvalNe;   
-    libGAP_EvalExprFuncs [ libGAP_T_LT             ] = libGAP_EvalLt;   
-    libGAP_EvalExprFuncs [ libGAP_T_GE             ] = libGAP_EvalGe;   
-    libGAP_EvalExprFuncs [ libGAP_T_GT             ] = libGAP_EvalGt;   
-    libGAP_EvalExprFuncs [ libGAP_T_LE             ] = libGAP_EvalLe;   
-    libGAP_EvalExprFuncs [ libGAP_T_IN             ] = libGAP_EvalIn;     
+    libGAP_InstallEvalExprFunc( libGAP_T_EQ             , libGAP_EvalEq);   
+    libGAP_InstallEvalExprFunc( libGAP_T_NE             , libGAP_EvalNe);   
+    libGAP_InstallEvalExprFunc( libGAP_T_LT             , libGAP_EvalLt);   
+    libGAP_InstallEvalExprFunc( libGAP_T_GE             , libGAP_EvalGe);   
+    libGAP_InstallEvalExprFunc( libGAP_T_GT             , libGAP_EvalGt);   
+    libGAP_InstallEvalExprFunc( libGAP_T_LE             , libGAP_EvalLe);   
+    libGAP_InstallEvalExprFunc( libGAP_T_IN             , libGAP_EvalIn);     
 
     /* the comparison operations are guaranteed to return booleans         */
-    libGAP_EvalBoolFuncs [ libGAP_T_EQ             ] = libGAP_EvalEq;
-    libGAP_EvalBoolFuncs [ libGAP_T_NE             ] = libGAP_EvalNe;
-    libGAP_EvalBoolFuncs [ libGAP_T_LT             ] = libGAP_EvalLt;
-    libGAP_EvalBoolFuncs [ libGAP_T_GE             ] = libGAP_EvalGe;
-    libGAP_EvalBoolFuncs [ libGAP_T_GT             ] = libGAP_EvalGt;
-    libGAP_EvalBoolFuncs [ libGAP_T_LE             ] = libGAP_EvalLe;
-    libGAP_EvalBoolFuncs [ libGAP_T_IN             ] = libGAP_EvalIn;
+    libGAP_InstallEvalBoolFunc( libGAP_T_EQ             , libGAP_EvalEq);
+    libGAP_InstallEvalBoolFunc( libGAP_T_NE             , libGAP_EvalNe);
+    libGAP_InstallEvalBoolFunc( libGAP_T_LT             , libGAP_EvalLt);
+    libGAP_InstallEvalBoolFunc( libGAP_T_GE             , libGAP_EvalGe);
+    libGAP_InstallEvalBoolFunc( libGAP_T_GT             , libGAP_EvalGt);
+    libGAP_InstallEvalBoolFunc( libGAP_T_LE             , libGAP_EvalLe);
+    libGAP_InstallEvalBoolFunc( libGAP_T_IN             , libGAP_EvalIn);
 
     /* install the evaluators for binary operations                        */
-    libGAP_EvalExprFuncs [ libGAP_T_SUM            ] = libGAP_EvalSum;
-    libGAP_EvalExprFuncs [ libGAP_T_AINV           ] = libGAP_EvalAInv;
-    libGAP_EvalExprFuncs [ libGAP_T_DIFF           ] = libGAP_EvalDiff;
-    libGAP_EvalExprFuncs [ libGAP_T_PROD           ] = libGAP_EvalProd;
-    libGAP_EvalExprFuncs [ libGAP_T_INV            ] = libGAP_EvalInv;
-    libGAP_EvalExprFuncs [ libGAP_T_QUO            ] = libGAP_EvalQuo;
-    libGAP_EvalExprFuncs [ libGAP_T_MOD            ] = libGAP_EvalMod;
-    libGAP_EvalExprFuncs [ libGAP_T_POW            ] = libGAP_EvalPow;
+    libGAP_InstallEvalExprFunc( libGAP_T_SUM            , libGAP_EvalSum);
+    libGAP_InstallEvalExprFunc( libGAP_T_AINV           , libGAP_EvalAInv);
+    libGAP_InstallEvalExprFunc( libGAP_T_DIFF           , libGAP_EvalDiff);
+    libGAP_InstallEvalExprFunc( libGAP_T_PROD           , libGAP_EvalProd);
+    libGAP_InstallEvalExprFunc( libGAP_T_INV            , libGAP_EvalInv);
+    libGAP_InstallEvalExprFunc( libGAP_T_QUO            , libGAP_EvalQuo);
+    libGAP_InstallEvalExprFunc( libGAP_T_MOD            , libGAP_EvalMod);
+    libGAP_InstallEvalExprFunc( libGAP_T_POW            , libGAP_EvalPow);
 
     /* install the evaluators for literal expressions                      */
-    libGAP_EvalExprFuncs [ libGAP_T_INT_EXPR       ] = libGAP_EvalIntExpr;
-    libGAP_EvalExprFuncs [ libGAP_T_TRUE_EXPR      ] = libGAP_EvalTrueExpr;
-    libGAP_EvalExprFuncs [ libGAP_T_FALSE_EXPR     ] = libGAP_EvalFalseExpr;
-    libGAP_EvalExprFuncs [ libGAP_T_CHAR_EXPR      ] = libGAP_EvalCharExpr;
-    libGAP_EvalExprFuncs [ libGAP_T_PERM_EXPR      ] = libGAP_EvalPermExpr;
+    libGAP_InstallEvalExprFunc( libGAP_T_INT_EXPR       , libGAP_EvalIntExpr);
+    libGAP_InstallEvalExprFunc( libGAP_T_TRUE_EXPR      , libGAP_EvalTrueExpr);
+    libGAP_InstallEvalExprFunc( libGAP_T_FALSE_EXPR     , libGAP_EvalFalseExpr);
+    libGAP_InstallEvalExprFunc( libGAP_T_CHAR_EXPR      , libGAP_EvalCharExpr);
+    libGAP_InstallEvalExprFunc( libGAP_T_PERM_EXPR      , libGAP_EvalPermExpr);
 
     /* install the evaluators for list and record expressions              */
-    libGAP_EvalExprFuncs [ libGAP_T_LIST_EXPR      ] = libGAP_EvalListExpr;
-    libGAP_EvalExprFuncs [ libGAP_T_LIST_TILD_EXPR ] = libGAP_EvalListTildeExpr;
-    libGAP_EvalExprFuncs [ libGAP_T_RANGE_EXPR     ] = libGAP_EvalRangeExpr;
-    libGAP_EvalExprFuncs [ libGAP_T_STRING_EXPR    ] = libGAP_EvalStringExpr;
-    libGAP_EvalExprFuncs [ libGAP_T_REC_EXPR       ] = libGAP_EvalRecExpr;
-    libGAP_EvalExprFuncs [ libGAP_T_REC_TILD_EXPR  ] = libGAP_EvalRecTildeExpr;
-    libGAP_EvalExprFuncs [ libGAP_T_FLOAT_EXPR_LAZY  ] = libGAP_EvalFloatExprLazy;
-    libGAP_EvalExprFuncs [ libGAP_T_FLOAT_EXPR_EAGER  ] = libGAP_EvalFloatExprEager;
+    libGAP_InstallEvalExprFunc( libGAP_T_LIST_EXPR      , libGAP_EvalListExpr);
+    libGAP_InstallEvalExprFunc( libGAP_T_LIST_TILD_EXPR , libGAP_EvalListTildeExpr);
+    libGAP_InstallEvalExprFunc( libGAP_T_RANGE_EXPR     , libGAP_EvalRangeExpr);
+    libGAP_InstallEvalExprFunc( libGAP_T_STRING_EXPR    , libGAP_EvalStringExpr);
+    libGAP_InstallEvalExprFunc( libGAP_T_REC_EXPR       , libGAP_EvalRecExpr);
+    libGAP_InstallEvalExprFunc( libGAP_T_REC_TILD_EXPR  , libGAP_EvalRecTildeExpr);
+    libGAP_InstallEvalExprFunc( libGAP_T_FLOAT_EXPR_LAZY  , libGAP_EvalFloatExprLazy);
+    libGAP_InstallEvalExprFunc( libGAP_T_FLOAT_EXPR_EAGER  , libGAP_EvalFloatExprEager);
 
     /* clear the tables for the printing dispatching                       */
     for ( type = 0; type < 256; type++ ) {
-        libGAP_PrintExprFuncs[ type ] = libGAP_PrintUnknownExpr;
+        libGAP_InstallPrintExprFunc( type , libGAP_PrintUnknownExpr);
     }
 
     /* install the printers for logical operations                         */
-    libGAP_PrintExprFuncs[ libGAP_T_OR             ] = libGAP_PrintBinop;
-    libGAP_PrintExprFuncs[ libGAP_T_AND            ] = libGAP_PrintBinop;
-    libGAP_PrintExprFuncs[ libGAP_T_NOT            ] = libGAP_PrintNot;
+    libGAP_InstallPrintExprFunc( libGAP_T_OR             , libGAP_PrintBinop);
+    libGAP_InstallPrintExprFunc( libGAP_T_AND            , libGAP_PrintBinop);
+    libGAP_InstallPrintExprFunc( libGAP_T_NOT            , libGAP_PrintNot);
 
     /* install the printers for comparison operations                      */
-    libGAP_PrintExprFuncs[ libGAP_T_EQ             ] = libGAP_PrintBinop;
-    libGAP_PrintExprFuncs[ libGAP_T_LT             ] = libGAP_PrintBinop;
-    libGAP_PrintExprFuncs[ libGAP_T_NE             ] = libGAP_PrintBinop;
-    libGAP_PrintExprFuncs[ libGAP_T_GE             ] = libGAP_PrintBinop;
-    libGAP_PrintExprFuncs[ libGAP_T_GT             ] = libGAP_PrintBinop;
-    libGAP_PrintExprFuncs[ libGAP_T_LE             ] = libGAP_PrintBinop;
-    libGAP_PrintExprFuncs[ libGAP_T_IN             ] = libGAP_PrintBinop;
+    libGAP_InstallPrintExprFunc( libGAP_T_EQ             , libGAP_PrintBinop);
+    libGAP_InstallPrintExprFunc( libGAP_T_LT             , libGAP_PrintBinop);
+    libGAP_InstallPrintExprFunc( libGAP_T_NE             , libGAP_PrintBinop);
+    libGAP_InstallPrintExprFunc( libGAP_T_GE             , libGAP_PrintBinop);
+    libGAP_InstallPrintExprFunc( libGAP_T_GT             , libGAP_PrintBinop);
+    libGAP_InstallPrintExprFunc( libGAP_T_LE             , libGAP_PrintBinop);
+    libGAP_InstallPrintExprFunc( libGAP_T_IN             , libGAP_PrintBinop);
 
     /* install the printers for binary operations                          */
-    libGAP_PrintExprFuncs[ libGAP_T_SUM            ] = libGAP_PrintBinop;
-    libGAP_PrintExprFuncs[ libGAP_T_AINV           ] = libGAP_PrintAInv;
-    libGAP_PrintExprFuncs[ libGAP_T_DIFF           ] = libGAP_PrintBinop;
-    libGAP_PrintExprFuncs[ libGAP_T_PROD           ] = libGAP_PrintBinop;
-    libGAP_PrintExprFuncs[ libGAP_T_INV            ] = libGAP_PrintInv;
-    libGAP_PrintExprFuncs[ libGAP_T_QUO            ] = libGAP_PrintBinop;
-    libGAP_PrintExprFuncs[ libGAP_T_MOD            ] = libGAP_PrintBinop;
-    libGAP_PrintExprFuncs[ libGAP_T_POW            ] = libGAP_PrintBinop;
+    libGAP_InstallPrintExprFunc( libGAP_T_SUM            , libGAP_PrintBinop);
+    libGAP_InstallPrintExprFunc( libGAP_T_AINV           , libGAP_PrintAInv);
+    libGAP_InstallPrintExprFunc( libGAP_T_DIFF           , libGAP_PrintBinop);
+    libGAP_InstallPrintExprFunc( libGAP_T_PROD           , libGAP_PrintBinop);
+    libGAP_InstallPrintExprFunc( libGAP_T_INV            , libGAP_PrintInv);
+    libGAP_InstallPrintExprFunc( libGAP_T_QUO            , libGAP_PrintBinop);
+    libGAP_InstallPrintExprFunc( libGAP_T_MOD            , libGAP_PrintBinop);
+    libGAP_InstallPrintExprFunc( libGAP_T_POW            , libGAP_PrintBinop);
 
     /* install the printers for literal expressions                        */
-    libGAP_PrintExprFuncs[ libGAP_T_INTEXPR        ] = libGAP_PrintIntExpr;
-    libGAP_PrintExprFuncs[ libGAP_T_INT_EXPR       ] = libGAP_PrintIntExpr;
-    libGAP_PrintExprFuncs[ libGAP_T_TRUE_EXPR      ] = libGAP_PrintTrueExpr;
-    libGAP_PrintExprFuncs[ libGAP_T_FALSE_EXPR     ] = libGAP_PrintFalseExpr;
-    libGAP_PrintExprFuncs[ libGAP_T_CHAR_EXPR      ] = libGAP_PrintCharExpr;
-    libGAP_PrintExprFuncs[ libGAP_T_PERM_EXPR      ] = libGAP_PrintPermExpr;
+    libGAP_InstallPrintExprFunc( libGAP_T_INTEXPR        , libGAP_PrintIntExpr);
+    libGAP_InstallPrintExprFunc( libGAP_T_INT_EXPR       , libGAP_PrintIntExpr);
+    libGAP_InstallPrintExprFunc( libGAP_T_TRUE_EXPR      , libGAP_PrintTrueExpr);
+    libGAP_InstallPrintExprFunc( libGAP_T_FALSE_EXPR     , libGAP_PrintFalseExpr);
+    libGAP_InstallPrintExprFunc( libGAP_T_CHAR_EXPR      , libGAP_PrintCharExpr);
+    libGAP_InstallPrintExprFunc( libGAP_T_PERM_EXPR      , libGAP_PrintPermExpr);
 
     /* install the printers for list and record expressions                */
-    libGAP_PrintExprFuncs[ libGAP_T_LIST_EXPR      ] = libGAP_PrintListExpr;
-    libGAP_PrintExprFuncs[ libGAP_T_LIST_TILD_EXPR ] = libGAP_PrintListExpr;
-    libGAP_PrintExprFuncs[ libGAP_T_RANGE_EXPR     ] = libGAP_PrintRangeExpr;
-    libGAP_PrintExprFuncs[ libGAP_T_STRING_EXPR    ] = libGAP_PrintStringExpr;
-    libGAP_PrintExprFuncs[ libGAP_T_FLOAT_EXPR_LAZY    ] = libGAP_PrintFloatExprLazy;
-    libGAP_PrintExprFuncs[ libGAP_T_FLOAT_EXPR_EAGER    ] = libGAP_PrintFloatExprEager;
-    libGAP_PrintExprFuncs[ libGAP_T_REC_EXPR       ] = libGAP_PrintRecExpr;
-    libGAP_PrintExprFuncs[ libGAP_T_REC_TILD_EXPR  ] = libGAP_PrintRecExpr;
+    libGAP_InstallPrintExprFunc( libGAP_T_LIST_EXPR      , libGAP_PrintListExpr);
+    libGAP_InstallPrintExprFunc( libGAP_T_LIST_TILD_EXPR , libGAP_PrintListExpr);
+    libGAP_InstallPrintExprFunc( libGAP_T_RANGE_EXPR     , libGAP_PrintRangeExpr);
+    libGAP_InstallPrintExprFunc( libGAP_T_STRING_EXPR    , libGAP_PrintStringExpr);
+    libGAP_InstallPrintExprFunc( libGAP_T_FLOAT_EXPR_LAZY    , libGAP_PrintFloatExprLazy);
+    libGAP_InstallPrintExprFunc( libGAP_T_FLOAT_EXPR_EAGER    , libGAP_PrintFloatExprEager);
+    libGAP_InstallPrintExprFunc( libGAP_T_REC_EXPR       , libGAP_PrintRecExpr);
+    libGAP_InstallPrintExprFunc( libGAP_T_REC_TILD_EXPR  , libGAP_PrintRecExpr);
 
     /* return success                                                      */
     return 0;
@@ -2157,7 +2163,6 @@ static libGAP_StructInitInfo libGAP_module = {
 
 libGAP_StructInitInfo * libGAP_InitInfoExprs ( void )
 {
-    libGAP_FillInVersion( &libGAP_module );
     return &libGAP_module;
 }
 
