@@ -78,6 +78,13 @@
 #include        "plist.h"               /* plain lists                     */
 #include        "string.h"              /* strings                         */
 
+#include	"code.h"		/* coder                           */
+#include	"aobjects.h"		/* atomic access to plists	   */
+#include	"thread.h"		/* threads			   */
+#include	"tls.h"			/* thread-local storage		   */
+
+#include	"ffdata.h"		/* pre-computed finite field data  */
+
 
 /****************************************************************************
 **
@@ -163,9 +170,9 @@ libGAP_Obj             libGAP_SuccFF;
 
 /****************************************************************************
 **
-*F  TYPE_FF(<ff>) . . . . . . . . . . . . . . .  kind of a small finite field
+*F  TYPE_FF(<ff>) . . . . . . . . . . . . . . .  type of a small finite field
 **
-**  'TYPE_FF' returns the kind of elements of the small finite field <ff>.
+**  'TYPE_FF' returns the type of elements of the small finite field <ff>.
 **
 **  Note that  'TYPE_FF' is a macro, so  do not call  it  with arguments that
 **  have side effects.
@@ -724,9 +731,9 @@ libGAP_Obj libGAP_FunDEGREE_FFE_DEFAULT (
 
 /****************************************************************************
 **
-*F  TypeFFE(<ffe>)  . . . . . . . . . . kind of element of small finite field
+*F  TypeFFE(<ffe>)  . . . . . . . . . . type of element of small finite field
 **
-**  'TypeFFE' returns the kind of the element <ffe> of a small finite field.
+**  'TypeFFE' returns the type of the element <ffe> of a small finite field.
 **
 **  'TypeFFE' is the function in 'TypeObjFuncs' for  elements in small finite
 **  fields.
@@ -1637,7 +1644,7 @@ libGAP_Obj libGAP_FuncIS_FFE (
     if ( libGAP_TNUM_OBJ(obj) == libGAP_T_FFE ) {
         return libGAP_True;
     }
-    else if ( libGAP_TNUM_OBJ(obj) <= libGAP_FIRST_EXTERNAL_TNUM ) {
+    else if ( libGAP_TNUM_OBJ(obj) < libGAP_FIRST_EXTERNAL_TNUM ) {
         return libGAP_False;
     }
     else {
@@ -1987,7 +1994,7 @@ static libGAP_Int libGAP_InitKernel (
     libGAP_InfoBags[ libGAP_T_FFE ].name = "ffe";
     /* InitMarkFuncBags( T_FFE, MarkNoSubBags ); */
 
-    /* install the kind function                                           */
+    /* install the type functions                                          */
     libGAP_ImportFuncFromLibrary( "TYPE_FFE", &libGAP_TYPE_FFE );
     libGAP_ImportFuncFromLibrary( "TYPE_FFE0", &libGAP_TYPE_FFE0 );
     libGAP_ImportFuncFromLibrary( "ZOp", &libGAP_ZOp );
@@ -2107,7 +2114,6 @@ static libGAP_StructInitInfo libGAP_module = {
 
 libGAP_StructInitInfo * libGAP_InitInfoFinfield ( void )
 {
-    libGAP_FillInVersion( &libGAP_module );
     return &libGAP_module;
 }
 
