@@ -181,7 +181,6 @@ void            libGAP_AssGVar (
     libGAP_Obj                 cops;           /* list of internal copies         */
     libGAP_Obj *               copy;           /* one copy                        */
     libGAP_UInt                i;              /* loop variable                   */
-    libGAP_Char *              name;           /* name of a function              */
     libGAP_Obj                 onam;           /* object of <name>                */
 
     /* make certain that the variable is not read only                     */
@@ -236,8 +235,7 @@ void            libGAP_AssGVar (
 
     /* assign name to a function                                           */
     if ( val != 0 && libGAP_TNUM_OBJ(val) == libGAP_T_FUNCTION && libGAP_NAME_FUNC(val) == 0 ) {
-        name = libGAP_NameGVar(gvar);
-        libGAP_C_NEW_STRING_DYN(onam, name);
+        onam = libGAP_CopyToStringRep(libGAP_NameGVarObj(gvar));
         libGAP_RESET_FILT_LIST( onam, libGAP_FN_IS_MUTABLE );
         libGAP_NAME_FUNC(val) = onam;
         libGAP_CHANGED_BAG(val);
