@@ -202,36 +202,6 @@ libGAP_UInt4 libGAP_nextrandMT_int32(libGAP_UInt4* mt)
     return y;
 }
 
-
-libGAP_Obj libGAP_FuncRandomListMT(libGAP_Obj self, libGAP_Obj mtstr, libGAP_Obj list)
-{
-  libGAP_Int len, a, lg;
-  libGAP_UInt4 *mt;
-  while ((! libGAP_IsStringConv(mtstr)) || libGAP_GET_LEN_STRING(mtstr) < 2500) {
-     mtstr = libGAP_ErrorReturnObj(
-         "<mtstr> must be a string with at least 2500 characters, ",
-         0L, 0L,
-         "you can replace <mtstr> via 'return <mtstr>;'" );
-  }
-  while (! libGAP_IS_LIST(list)) {
-     list = libGAP_ErrorReturnObj(
-         "<list> must be a list, not a %s",
-         (libGAP_Int)libGAP_TNAM_OBJ(list), 0L,
-         "you can replace <list> via 'return <list>;'" );
-  }
-  len = libGAP_LEN_LIST(list);
-  if (len == 0) return libGAP_Fail;
-  mt = (libGAP_UInt4*) libGAP_CHARS_STRING(mtstr);
-  lg = 31 - libGAP_CLog2Int(len);
-  for (a = libGAP_nextrandMT_int32(mt) >> lg;
-       a >= len;
-       a = libGAP_nextrandMT_int32(mt) >> lg
-    );
-  return libGAP_ELM_LIST(list, a+1);
-}
-
-
-
 /****************************************************************************
 **
 *F  FuncHASHKEY_BAG(<self>,<obj>,<seed>,<offset>,<maxlen>)
@@ -678,9 +648,6 @@ static libGAP_StructGVarFunc libGAP_GVarFuncs [] = {
     { "InitRandomMT", 1, "initstr",
       libGAP_FuncInitRandomMT, "src/integer.c:InitRandomMT" },
 
-    { "RandomListMT", 2, "mtstr, list",
-      libGAP_FuncRandomListMT, "src/integer.c:RandomListMT" },
-
     { 0 }
 
 };
