@@ -232,8 +232,10 @@ libGAP_Obj            libGAP_RemPlist (
     }
     removed = libGAP_ELM_PLIST(list, pos);
     libGAP_SET_ELM_PLIST(list, pos, (libGAP_Obj)0L);
-    libGAP_SET_LEN_PLIST(list, pos-1);
-    if ( pos == 1 ) {
+    pos--;
+    while ( 1 <= pos && libGAP_ELM_PLIST( list, pos ) == 0 ) { pos--; }
+    libGAP_SET_LEN_PLIST(list, pos);
+    if ( pos == 0 ) {
       libGAP_RetypeBag(list, libGAP_T_PLIST_EMPTY);
     }
     if (4*pos*sizeof(libGAP_Obj) < 3*libGAP_SIZE_BAG(list))
@@ -302,6 +304,7 @@ libGAP_Obj             libGAP_FuncAPPEND_LIST_INTR (
         len2 = libGAP_GET_LEN_STRING(list2);
         libGAP_GROW_STRING(list1, len1 + len2);
         libGAP_SET_LEN_STRING(list1, len1 + len2);
+        libGAP_CLEAR_FILTS_LIST(list1);
         memmove( (void *)(libGAP_CHARS_STRING(list1) + len1), 
                 (void *)libGAP_CHARS_STRING(list2), len2 + 1);
         /* ensure trailing zero */
