@@ -722,7 +722,7 @@ libGAP_Obj libGAP_InnerRecNames( libGAP_Obj rec )
     libGAP_UInt                rnam;           /* one name of record              */
     libGAP_Obj                 string;         /* one name as string              */
     libGAP_UInt                i;
-
+    libGAP_Obj                 name;
     libGAP_SortPRecRNam(rec,0);   /* Make sure rnams are sorted and thus negative */
 
     /* allocate the list                                                   */
@@ -733,7 +733,8 @@ libGAP_Obj libGAP_InnerRecNames( libGAP_Obj rec )
     for ( i = 1; i <= libGAP_LEN_PREC(rec); i++ ) {
         rnam = -(libGAP_Int)(libGAP_GET_RNAM_PREC( rec, i ));
         /* could have been moved by garbage collection */
-        libGAP_C_NEW_STRING_DYN( string, libGAP_NAME_RNAM(rnam) );
+        name = libGAP_NAME_OBJ_RNAM( rnam );
+        string = libGAP_CopyToStringRep( name );
         libGAP_SET_ELM_PLIST( list, i, string );
         libGAP_CHANGED_BAG( list );
     }
@@ -1083,6 +1084,3 @@ libGAP_StructInitInfo * libGAP_InitInfoPRecord ( void )
 
 *E  precord.c . . . . . . . . . . . . . . . . . . . . . . . . . . . ends here
 */
-
-
-
