@@ -509,6 +509,73 @@ libGAP_Obj libGAP_ProfileEvalBoolPassthrough(libGAP_Expr stat)
 }
 
 
+/****************************************************************************
+**
+** This functions check if we overflow either 2^16 lines, or files.
+** In this case profiling will "give up". We print a warning to tell users
+** that this happens.
+**/
+
+libGAP_Int libGAP_HaveReportedLineProfileOverflow;
+libGAP_Int libGAP_ShouldReportLineProfileOverflow;
+
+libGAP_Int libGAP_HaveReportedFileProfileOverflow;
+libGAP_Int libGAP_ShouldReportFileProfileOverflow;
+
+// This function only exists to allow testing of these overflow checks
+libGAP_Obj libGAP_FuncCLEAR_PROFILE_OVERFLOW_CHECKS(libGAP_Obj self) {
+  libGAP_HaveReportedLineProfileOverflow = 0;
+  libGAP_ShouldReportLineProfileOverflow = 0;
+
+  libGAP_HaveReportedFileProfileOverflow = 0;
+  libGAP_ShouldReportFileProfileOverflow = 0;
+  
+  return 0;
+}
+
+void libGAP_CheckPrintOverflowWarnings() {
+    if(!libGAP_HaveReportedLineProfileOverflow && libGAP_ShouldReportLineProfileOverflow)
+    {
+      libGAP_HaveReportedLineProfileOverflow = 1;
+      libGAP_Pr("#I Profiling only works on the first 65,535 lines of each file\n"
+         "#I (this warning will only appear once).\n",
+          0L, 0L);
+    }
+    
+    if(!libGAP_HaveReportedFileProfileOverflow && libGAP_ShouldReportFileProfileOverflow)
+    {
+      libGAP_HaveReportedFileProfileOverflow = 1;
+      libGAP_Pr("#I Profiling only works for the first 65,535 read files\n"
+         "#I (this warning will only appear once).\n",
+          0L, 0L );
+    }
+}
+
+void libGAP_RegisterProfilingLineOverflowOccured()
+{
+    libGAP_Int active;
+    libGAP_HashLock(&libGAP_profileState);
+    active = libGAP_profileState_Active;
+    libGAP_HashUnlock(&libGAP_profileState);
+    libGAP_ShouldReportLineProfileOverflow = 1;
+    if(active)
+    {
+        libGAP_CheckPrintOverflowWarnings();
+    }
+}
+
+void libGAP_RegisterProfilingFileOverflowOccured()
+{
+    libGAP_Int active;
+    libGAP_HashLock(&libGAP_profileState);
+    active = libGAP_profileState_Active;
+    libGAP_HashUnlock(&libGAP_profileState);
+    libGAP_ShouldReportFileProfileOverflow = 1;
+    if(active)
+    {
+        libGAP_CheckPrintOverflowWarnings();
+    }
+}
 
 /****************************************************************************
 **
@@ -603,7 +670,7 @@ libGAP_Obj libGAP_FuncACTIVATE_PROFILING (
     if(libGAP_profileState_Active) {
       return libGAP_Fail;
     }
-    
+
     if(libGAP_profileState.profiledPreviously &&
        coverage == libGAP_True) {
         libGAP_ErrorMayQuit("Code coverage can only be started once per"
@@ -611,6 +678,8 @@ libGAP_Obj libGAP_FuncACTIVATE_PROFILING (
         return libGAP_Fail;
     }
 
+    libGAP_CheckPrintOverflowWarnings();
+
     libGAP_OutputtedFilenameList = libGAP_NEW_PLIST(libGAP_T_PLIST, 0);
 
     if ( ! libGAP_IsStringConv( filename ) ) {
@@ -897,6 +966,8 @@ void libGAP_RegisterStatWithProfiling(libGAP_Stat stat)
 }
 
 
+
+
 /****************************************************************************
 **
 
@@ -913,6 +984,8 @@ static libGAP_StructGVarFunc libGAP_GVarFuncs [] = {
       libGAP_FuncACTIVATE_PROFILING, "src/profile.c:ACTIVATE_PROFILING" },
     { "DEACTIVATE_PROFILING", 0, "",
       libGAP_FuncDEACTIVATE_PROFILING, "src/profile.c:DEACTIVATE_PROFILING" },
+    { "CLEAR_PROFILE_OVERFLOW_CHECKS", 0, "",
+      libGAP_FuncCLEAR_PROFILE_OVERFLOW_CHECKS, "src/profile.c:CLEAR_PROFILE_OVERFLOW_CHECKS" },
     { "IsLineByLineProfileActive", 0, "",
       libGAP_FuncIS_PROFILE_ACTIVE, "src/profile.c:IsLineByLineProfileActive" },
     { "ACTIVATE_COLOR_PROFILING", 1, "bool",
