@@ -77,6 +77,10 @@
 
 #include        "saveload.h"            /* saving and loading              */
 
+#include	"code.h"		/* coder                           */
+#include	"thread.h"		/* threads			   */
+#include	"tls.h"			/* thread-local storage		   */
+
 
 /****************************************************************************
 **
@@ -233,7 +237,7 @@
 /****************************************************************************
 **
 
-*F  TypeRangeNSortImmutable( <range> )  . . . . . . . . . . . kind of a range
+*F  TypeRangeNSortImmutable( <range> )  . . . . . . . . . . . type of a range
 **
 **  'TypeRangeNSortMutable' is the   function in 'TypeObjFuncs' for immutable
 **  ranges which are not strictly sorted.
@@ -248,7 +252,7 @@ libGAP_Obj libGAP_TypeRangeNSortImmutable (
     
 /****************************************************************************
 **
-*F  TypeRangeNSortMutable( <range> )  . . . . . . . . . . . . kind of a range
+*F  TypeRangeNSortMutable( <range> )  . . . . . . . . . . . . type of a range
 **
 **  'TypeRangeNSortMutable' is the   function in 'TypeObjFuncs' for   mutable
 **  ranges which are not strictly sorted.
@@ -263,7 +267,7 @@ libGAP_Obj libGAP_TypeRangeNSortMutable (
     
 /****************************************************************************
 **
-*F  TypeRangeSSortImmutable( <range> )  . . . . . . . . . . . kind of a range
+*F  TypeRangeSSortImmutable( <range> )  . . . . . . . . . . . type of a range
 **
 **  'TypeRangeNSortMutable' is the   function in 'TypeObjFuncs' for immutable
 **  ranges which are strictly sorted.
@@ -279,7 +283,7 @@ libGAP_Obj libGAP_TypeRangeSSortImmutable (
 
 /****************************************************************************
 **
-*F  TypeRangeSSortMutable( <range> )  . . . . . . . . . . . . kind of a range
+*F  TypeRangeSSortMutable( <range> )  . . . . . . . . . . . . type of a range
 **
 **  'TypeRangeNSortMutable' is the   function in 'TypeObjFuncs' for   mutable
 **  ranges which are strictly sorted.
@@ -1242,7 +1246,7 @@ static libGAP_Int libGAP_egcd (libGAP_Int a, libGAP_Int b, libGAP_Int *lastx, li
 
 libGAP_Obj libGAP_FuncINTER_RANGE( libGAP_Obj self, libGAP_Obj r1, libGAP_Obj r2)
 {
-  libGAP_Int low1, low2, inc1, inc2, lowi, inci, libGAP_g, x, y;
+  libGAP_Int low1, low2, inc1, inc2, lowi, inci, g, x, y;
   libGAP_UInt len1, len2, leni;
   
   low1 = libGAP_GET_LOW_RANGE(r1);
@@ -1272,19 +1276,19 @@ libGAP_Obj libGAP_FuncINTER_RANGE( libGAP_Obj self, libGAP_Obj r1, libGAP_Obj r2
       ut = len1; len1 = len2; len2 = ut;
     }
 
-  libGAP_g = libGAP_egcd(inc1, inc2, &x, &y);
+  g = libGAP_egcd(inc1, inc2, &x, &y);
 
-  inci = (inc1 / libGAP_g) * inc2;
+  inci = (inc1 / g) * inc2;
 
-  if (inci / inc2 != inc1 / libGAP_g) /* overflow */
+  if (inci / inc2 != inc1 / g) /* overflow */
     goto empty_range;
 
-  if ((low2 - low1) % libGAP_g) /* ranges are disjoint */
+  if ((low2 - low1) % g) /* ranges are disjoint */
     goto empty_range;
 
-  x = (-y * ((low2 - low1) / libGAP_g)) % (inc1 / libGAP_g);
+  x = (-y * ((low2 - low1) / g)) % (inc1 / g);
   if (x < 0)
-    x += inc1/libGAP_g;
+    x += inc1/g;
   lowi = low2 + inc2 * x;
 
   x = (low1 + (len1-1)*inc1 - lowi);
@@ -1595,7 +1599,11 @@ static libGAP_Int libGAP_InitKernel (
     libGAP_InitMarkFuncBags(   libGAP_T_RANGE_SSORT            +libGAP_COPYING , libGAP_MarkAllSubBags );
     libGAP_InitMarkFuncBags(   libGAP_T_RANGE_SSORT +libGAP_IMMUTABLE +libGAP_COPYING , libGAP_MarkAllSubBags );
 
-    /* install the kind function                                           */
+    /* Make immutable bags public                                          */
+    libGAP_MakeBagTypePublic( libGAP_T_RANGE_NSORT + libGAP_IMMUTABLE );
+    libGAP_MakeBagTypePublic( libGAP_T_RANGE_SSORT + libGAP_IMMUTABLE );
+
+    /* install the type function                                           */
     libGAP_ImportGVarFromLibrary( "TYPE_RANGE_NSORT_MUTABLE",
                            &libGAP_TYPE_RANGE_NSORT_MUTABLE );
 
@@ -1789,7 +1797,6 @@ static libGAP_StructInitInfo libGAP_module = {
 
 libGAP_StructInitInfo * libGAP_InitInfoRange ( void )
 {
-    libGAP_FillInVersion( &libGAP_module );
     return &libGAP_module;
 }
 
