@@ -249,7 +249,7 @@ libGAP_Obj             libGAP_NameRNamHandler (
     libGAP_Obj                 rnam )
 {
     libGAP_Obj                 name;
-    libGAP_Char                *cname;
+    libGAP_Obj                 oname;
     while ( ! libGAP_IS_INTOBJ(rnam)
          || libGAP_INT_INTOBJ(rnam) <= 0
         || libGAP_CountRNam < libGAP_INT_INTOBJ(rnam) ) {
@@ -258,8 +258,8 @@ libGAP_Obj             libGAP_NameRNamHandler (
             (libGAP_Int)libGAP_TNAM_OBJ(rnam), 0L,
             "you can replace <rnam> via 'return <rnam>;'" );
     }
-    cname = libGAP_NAME_RNAM( libGAP_INT_INTOBJ(rnam) );
-    libGAP_C_NEW_STRING_DYN( name, cname);
+    oname = libGAP_NAME_OBJ_RNAM( libGAP_INT_INTOBJ(rnam) );
+    name = libGAP_CopyToStringRep(oname);
     return name;
 }
 
@@ -558,12 +558,12 @@ libGAP_Obj libGAP_FuncALL_RNAMES (
 {
     libGAP_Obj                 copy, s;
     libGAP_UInt                i;
-    libGAP_Char*               name;
+    libGAP_Obj                 name;
 
     copy = libGAP_NEW_PLIST( libGAP_T_PLIST+libGAP_IMMUTABLE, libGAP_CountRNam );
     for ( i = 1;  i <= libGAP_CountRNam;  i++ ) {
-        name = libGAP_NAME_RNAM( i );
-        libGAP_C_NEW_STRING_DYN(s, name);
+        name = libGAP_NAME_OBJ_RNAM( i );
+        s = libGAP_CopyToStringRep(name);
         libGAP_SET_ELM_PLIST( copy, i, s );
     }
     libGAP_SET_LEN_PLIST( copy, libGAP_CountRNam );
@@ -784,4 +784,3 @@ libGAP_StructInitInfo * libGAP_InitInfoRecords ( void )
 
 *E  records.c . . . . . . . . . . . . . . . . . . . . . . . . . . . ends here
 */
-
