@@ -924,7 +924,7 @@ static void libGAP_PrSavedObj( libGAP_UInt x)
   if ((x & 3) == 1)
     libGAP_Pr("Immediate  integer %d\n", libGAP_INT_INTOBJ((libGAP_Obj)x),0L);
   else if ((x & 3) == 2)
-    libGAP_Pr("Immedate FFE %d %d\n", libGAP_VAL_FFE(x), libGAP_SIZE_FF(libGAP_FLD_FFE(x)));
+    libGAP_Pr("Immediate FFE %d %d\n", libGAP_VAL_FFE(x), libGAP_SIZE_FF(libGAP_FLD_FFE(x)));
   else
     libGAP_Pr("Reference to bag number %d\n",x>>2,0L);
 }
