@@ -1947,25 +1947,30 @@ libGAP_Obj libGAP_FuncWRITE_STRING_FILE_NC (
     libGAP_Obj             fid,
     libGAP_Obj             str )
 {
-    libGAP_Int             len = 0, ret;
+    libGAP_Int             len = 0, l, ret;
+    char            *ptr;
 
     /* don't check the argument                                            */
     
     len = libGAP_GET_LEN_STRING(str);
-    ret = write( libGAP_syBuf[libGAP_INT_INTOBJ(fid)].echo, libGAP_CHARS_STRING(str), len);
-    return (ret == len)?libGAP_True : libGAP_Fail;
+    ptr = libGAP_CSTR_STRING(str);
+    while (len > 0) {
+      l = (len > 1048576) ? 1048576 : len;
+      ret = write( libGAP_syBuf[libGAP_INT_INTOBJ(fid)].echo, ptr, l);
+      if (ret == -1) {
+        libGAP_SySetErrorNo();
+        return libGAP_Fail;
+      }
+      len -= ret;
+      ptr += ret;
+    }
+    return libGAP_True;
 }
 
-
 libGAP_Obj libGAP_FuncREAD_STRING_FILE (
     libGAP_Obj             self,
     libGAP_Obj             fid )
 {
-    libGAP_Char            buf[20001];
-    libGAP_Int             ret, len;
-    libGAP_UInt            lstr;
-    libGAP_Obj             str;
-
     /* check the argument                                                  */
     while ( ! libGAP_IS_INTOBJ(fid) ) {
         fid = libGAP_ErrorReturnObj(
@@ -1973,56 +1978,7 @@ libGAP_Obj libGAP_FuncREAD_STRING_FILE (
             (libGAP_Int)libGAP_TNAM_OBJ(fid), 0L,
             "you can replace <fid> via 'return <fid>;'" );
     }
-
-#if ! SYS_IS_CYGWIN32
-    /* fstat seems completely broken under CYGWIN */
-#if HAVE_STAT
-    /* first try to get the whole file as one chunk, this avoids garbage
-       collections because of the GROW_STRING calls below    */
-    {
-        struct stat fstatbuf;
-        if ( libGAP_syBuf[libGAP_INT_INTOBJ(fid)].pipe == 0 &&
-            fstat( libGAP_syBuf[libGAP_INT_INTOBJ(fid)].fp, &fstatbuf) == 0 ) {
-            if((off_t)(libGAP_Int)fstatbuf.st_size != fstatbuf.st_size) {
-                libGAP_ErrorMayQuit(
-                    "The file is too big to fit the current workspace",
-                    (libGAP_Int)0, (libGAP_Int)0);
-            }
-            len = (libGAP_Int) fstatbuf.st_size;
-            str = libGAP_NEW_STRING( len );
-            ret = read( libGAP_syBuf[libGAP_INT_INTOBJ(fid)].fp, 
-                        libGAP_CHARS_STRING(str), len);
-            libGAP_CHARS_STRING(str)[ret] = '\0';
-            libGAP_SET_LEN_STRING(str, ret);
-            if ( (off_t) ret == fstatbuf.st_size ) {
-                 return str;
-            }
-        }
-    }
-#endif
-#endif
-    /* read <fid> until we see  eof   (in 20kB pieces)                     */
-    str = libGAP_NEW_STRING(0);
-    len = 0;
-    while (1) {
-        if ( (ret = read( libGAP_syBuf[libGAP_INT_INTOBJ(fid)].fp , buf, 20000)) <= 0 )
-            break;
-        len += ret;
-        libGAP_GROW_STRING( str, len );
-	lstr = libGAP_GET_LEN_STRING(str);
-        memcpy( libGAP_CHARS_STRING(str)+lstr, buf, ret );
-	*(libGAP_CHARS_STRING(str)+lstr+ret) = '\0';
-	libGAP_SET_LEN_STRING(str, lstr+ret);
-    }
-
-    /* fix the length of <str>                                             */
-    len = libGAP_GET_LEN_STRING(str);
-    libGAP_ResizeBag( str, libGAP_SIZEBAG_STRINGLEN(len) );
-
-    /* and return */
-
-    libGAP_syBuf[libGAP_INT_INTOBJ(fid)].ateof = 1;
-    return len == 0 ? libGAP_Fail : str;
+    return libGAP_SyReadStringFid(libGAP_INT_INTOBJ(fid));
 }
 
 /****************************************************************************
